@@ -4,5 +4,5 @@ pub mod normal;
 /// Ticked combinator.
 pub mod ticked;
 
-pub use normal::facet_map;
-pub use ticked::facet_map_t;
+pub use normal::{facet, facet_map};
+pub use ticked::{facet_map_t, facet_t};
